# A django admin extension for importing exporting records from/to xls/ods

A Python library project using:
* pytest
* flake8
* tox
* bumpversion
* isort

* Free software: MIT license
* Documentation: __TBD__


Features
--------

* TODO

Credits
-------

